Prelude module for convenient imports
Re-exports
pub use crate::action::Action;pub use crate::action::ActionCategory;pub use crate::action::ActionParams;pub use crate::bus::process_raw_event;pub use crate::bus::spawn_event_poller;pub use crate::bus::DefaultBindingContext;pub use crate::bus::EventBus;pub use crate::bus::EventHandler;pub use crate::bus::EventOutcome;pub use crate::bus::EventRoutingState;pub use crate::bus::HandlerResponse;pub use crate::bus::RawEvent;pub use crate::bus::RouteTarget;pub use crate::bus::RoutedEvent;pub use crate::bus::SimpleEventBus;pub use crate::component::Component;pub use crate::event::ComponentId;pub use crate::event::Event;pub use crate::event::EventContext;pub use crate::event::EventKind;pub use crate::event::EventType;pub use crate::event::GlobalKeyPolicy;pub use crate::event::NumericComponentId;pub use crate::features::DynamicFeatures;pub use crate::features::FeatureFlags;pub use crate::keybindings::format_key_for_display;pub use crate::keybindings::parse_key_string;pub use crate::keybindings::BindingContext;pub use crate::keybindings::Keybindings;pub use crate::resource::DataResource;pub use crate::store::ComposedMiddleware;pub use crate::store::DispatchError;pub use crate::store::DispatchLimits;pub use crate::store::Middleware;pub use crate::store::NoEffect;pub use crate::store::NoopMiddleware;pub use crate::store::Reducer;pub use crate::store::ReducerResult;pub use crate::store::Store;pub use crate::store::StoreWithMiddleware;pub use crate::runtime::DispatchErrorPolicy;pub use crate::runtime::EffectContext;pub use crate::runtime::PollerConfig;pub use crate::runtime::RenderContext;pub use crate::runtime::Runtime;pub use crate::runtime::RuntimeStore;
Macros
- reducer_
compose - Compose a reducer by routing actions to focused handlers.
Structs
- Frame
- A consistent view into the terminal state for rendering a single frame.
- Line
- A line of text, consisting of one or more
Spans. - Modifier
- Modifier changes the way a piece of text is displayed.
- Rect
- A Rectangular area.
- Span
- Represents a part of a line that is contiguous and where all characters share the same style.
- Style
- Style lets you control the main characteristics of the displayed elements.
- Text
- A string split over one or more lines.
Enums
- Color
- ANSI Color